C$Procedure GETIK ( Get ASPERA IK Data )
 
      SUBROUTINE GETIK ( SENSOR, SENSNM, SENSID, SECNUM, 
     .                   SECSIZ, SECFRM, SECDIR          )
 
C$ Abstract
C
C          Return IK data for a given ASPERA sensor. 
C
C$ Copyright
C
C     Copyright (2003), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     KERNEL Required Reading (kernel.req)
C     Latest ASPERA IK File (mex_aspera_vXX.ti)
C     Latest MEX FK File (mex_vXX.tf)
C
C$ Keywords
C
C     KERNEL
C     UTILITY
C
C$ Declarations
 
      IMPLICIT NONE
        
      CHARACTER*(*)         SENSOR
      CHARACTER*(*)         SENSNM
      INTEGER               SENSID
      INTEGER               SECNUM ( 2 )
      DOUBLE PRECISION      SECSIZ ( 2 )
      CHARACTER*(*)         SECFRM
      DOUBLE PRECISION      SECDIR ( 3, * )
        
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     SENSOR     I   ASPERA sensor acronym -- ELS, NPD, NPI, or IMA
C     SENSNM     O   Full NAIF name of the sensor
C     SENSID     O   NAIF ID of the sensor
C     SECNUM     O   Sector grid dimensions (in-plane, normal to plane)
C     SECSIZ     O   Sector size, degrees (in-plane, normal to plane)
C     SECFRM     O   Frame in which in-plane view directions are defined
C     SECDIR     O   In-plane sector center view directions
C
C$ Detailed_Input
C 
C     SENSOR         ASPERA sensor acronym -- ELS, NPD, NPI, or IMA.
C                   
C$ Detailed_Output
C 
C     SENSNM     is the full NAIF name of the sensor indicated by 
C                the input argument SENSOR.  For example, the 
C                acronym ELS maps to the full name MEX_ASPERA_ELS.
C 
C     SENSID     is the NAIF integer ID code of the sensor.  The
C                association of sensor names and codes is established
C                in the MEX frame kernel.
C
C     SECNUM     is an array of two integers giving the sector grid 
C                dimensions (in-plane, normal to plane).
C
C     SECSIZ     is an array of two double precision numbers giving
C                the sector size in degrees (in-plane, normal to plane).
C
C     SECFRM     the name of the reference frame in which the in-plane
C                view directions are defined.
C
C     SECDIR     is an array of in-plane sector center view direction
C                vectors.  The number of vectors is SECNUM(1).
C                The Ith vector resides in array elements
C
C                    SECDIR(J,I)    J  = 1, 2, 3
C 
C$ Parameters
C 
C     None.
C 
C$ Files
C 
C     MEX FK and ASPERA IK files must be loaded prior to calling this
C     subroutine.
C 
C$ Exceptions
C
C     1) If NAIF name <-> ID mapping for MEX instruments provided in
C        the MEX FK file have not been loaded, then the error
C        NOIDMAPPINGDATA is signaled.
C
C     2) If any of the expected IK keywords provided in the ASPERA IK
C        file have not been found in the POOL, then the error NOIKDATA
C        is signaled.
C
C     3) If not enough space should be provided for the arguments
C        SENSNM, SECFRM, SECDIR, then memory violations will occur.
C
C$ Particulars
C
C     The MEX FK file loaded prior to calling this routine should
C     contain MEX instrument <-> NAIF ID mappings.
C
C     ASPERA IK file loaded prior to calling this routine should contain
C     the following keywords for each of the sensors:
C
C        INS#_NUMBER_OF_SECTORS
C        INS#_SECTOR_SIZE
C        INS#_FRAME
C        INS#_SECTOR_DIRECTIONS
C
C$ Examples
C
C
C     In this example the program gets and prints out IK data for ELS.
C
C        PROGRAM IKELS
C        IMPLICIT NONE
C
C
C        INTEGER               NSEC
C        PARAMETER           ( NSEC   = 32 )
C
C        INTEGER               NAMLEN
C        PARAMETER           ( NAMLEN = 32 )
C
C        CHARACTER*(NAMLEN)    SECFRM
C        CHARACTER*(NAMLEN)    SENSNM
C
C        DOUBLE PRECISION      SECDIR ( 3, 32 )
C
C        INTEGER               I
C        INTEGER               J
C        INTEGER               SECNUM ( 2 )
C        DOUBLE PRECISION      SECSIZ ( 2 )
C        INTEGER               SENSID
C
C  C
C  C     Load MEX FK and ASPERA IK files.
C  C
C        CALL FURNSH ( 'mex_v03.tf'        )
C        CALL FURNSH ( 'mex_aspera_v01.ti' )
C
C  C
C  C     Get ELS IK data.
C  C
C        CALL GETIK( 'ELS',  SENSNM, SENSID, SECNUM,
C       .            SECSIZ, SECFRM, SECDIR         )
C
C  C
C  C     Report ELS IK data.
C  C
C        WRITE ( *, '(1X,2A      )' ) 'SENSOR NAIF NAME:  ', SENSNM
C        WRITE ( *, '(1X,A,I9    )' ) 'SENSOR NAIF ID:    ', SENSID
C        WRITE ( *, '(1X,A,2I5   )' ) 'NUMBER OF SECTORS: ', SECNUM
C        WRITE ( *, '(1X,A,2F9.3 )' ) 'SECTOR SIZE:       ', SECSIZ
C        WRITE ( *, '(1X,2A      )' ) 'REFERENCE FRAME:   ', SECFRM
C        WRITE ( *, '(1X,A       )' ) 'SECTOR VIEW DIRECTIONS:'
C
C        DO I = 1, SECNUM(1)
C           WRITE ( *, '(1X,3F12.9)' ) ( SECDIR(J,I), J = 1, 3 )
C        END DO
C
C        END
C
C
C$ Restrictions
C 
C     None.
C
C$ Author_and_Institution
C 
C     B.V. Semenov    (JPL)
C     N.J. Bachman    (JPL)
C 
C$ Literature_References
C 
C     None.
C 
C$ Version
C 
C-    GETIK Version 1.0.0, 15-AUG-2003 (BVS) (NJB)
C
C-&

C
C     Local parameters
C     
      INTEGER               NAMLEN
      PARAMETER           ( NAMLEN = 32 )

C
C     Local variables
C     
      CHARACTER*(NAMLEN)    IKKWD

      INTEGER               N

      LOGICAL               FOUND

C
C     Since all IK variable names contain NAIF ID of the instrument,
C     the input sensor acronym, NNN, needs to be expanded into its
C     full name, MEX_ASPERA_NNN, which then can be used to find the
C     sensor's NAIF ID code.
C
      SENSNM = 'MEX_ASPERA_'
      CALL SUFFIX ( SENSOR, 0, SENSNM )
 
      CALL BODN2C ( SENSNM, SENSID, FOUND )

      IF ( .NOT. FOUND ) THEN

         CALL SETMSG ( 'Cannot determine NAIF ID for #.' )
         CALL ERRCH  ( '#', SENSNM                       )
         CALL SIGERR ( 'NOIDMAPPINGDATA'                 )
         RETURN

      END IF

C
C     Now IK routines can be used to retrieve loaded data.  First,
C     retrieve the number of sectors provided in the
C     INS-NNNNNN_NUMBER_OF_SECTORS keyword (here -NNNNNN is the NAIF ID
C     of the sensor.)
C
      IKKWD = 'INS#_NUMBER_OF_SECTORS'
      CALL REPMI  ( IKKWD, '#', SENSID, IKKWD )

      CALL GIPOOL ( IKKWD, 0, 2, N, SECNUM, FOUND )

      IF ( .NOT. FOUND ) THEN

         CALL SETMSG ( 'Loaded IK does not contain #.' )
         CALL ERRCH  ( '#', IKKWD                      )
         CALL SIGERR ( 'NOIKDATA'                      )
         RETURN

      END IF

C    
C     Second, retrieve the sector size provided in the
C     INS-NNNNNN_SECTOR_SIZE keyword.
C
      IKKWD = 'INS#_SECTOR_SIZE'
      CALL REPMI  ( IKKWD, '#', SENSID, IKKWD )

      CALL GDPOOL ( IKKWD, 0, 2, N, SECSIZ, FOUND )

      IF ( .NOT. FOUND ) THEN

         CALL SETMSG ( 'Loaded IK does not contain #.' )
         CALL ERRCH  ( '#', IKKWD                      )
         CALL SIGERR ( 'NOIKDATA'                      )
         RETURN

      END IF

C 
C     Third, retrieve the frame in which sector view direction are
C     defined. It is provided in the INS-NNNNNN_FRAME keyword.
C
      IKKWD = 'INS#_FRAME'
      CALL REPMI  ( IKKWD, '#', SENSID, IKKWD )

      CALL GCPOOL ( IKKWD, 0, 1, N, SECFRM, FOUND )

      IF ( .NOT. FOUND ) THEN

         CALL SETMSG ( 'Loaded IK does not contain #.' )
         CALL ERRCH  ( '#', IKKWD                      )
         CALL SIGERR ( 'NOIKDATA'                      )
         RETURN

      END IF

C
C     Last, retrieve the sector view directions provided in the 
C     INS-NNNNNN_SECTOR_DIRECTIONS keyword.
C
      IKKWD = 'INS#_SECTOR_DIRECTIONS '
      CALL REPMI  ( IKKWD, '#', SENSID, IKKWD )

      CALL GDPOOL ( IKKWD, 0, SECNUM(1)*3, N, SECDIR, FOUND )

      IF ( .NOT. FOUND ) THEN

         CALL SETMSG ( 'Loaded IK does not contain #.' )
         CALL ERRCH  ( '#', IKKWD                      )
         CALL SIGERR ( 'NOIKDATA'                      )
         RETURN

      END IF

      END


 
