C$Procedure CHECKCK ( Check for S/C and ASPERA CK Data Availability )
 
      SUBROUTINE CHECKCK ( ET, GOTSCATT, GOTSCANATT )
 
C$ Abstract
C
C     Return flags indicating if MEX s/c and ASPERA scanner orientation
C     data are available in loaded CK files for specified ET . 
C
C$ Copyright
C
C     Copyright (2003), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     CK Required Reading (ck.req)
C     SCLK Required Reading (sclk.req) 
C     Latest MEX FK File (mex_vXX.tf)
C
C$ Keywords
C
C     KERNEL
C     UTILITY
C
C$ Declarations
 
      IMPLICIT NONE
        
      DOUBLE PRECISION      ET
      LOGICAL               GOTSCATT
      LOGICAL               GOTSCANATT
 
C$ Brief_I/O
C
C     VARIABLE   I/O  DESCRIPTION
C     --------   ---  --------------------------------------------------
C     ET          I   Ephemeris time of interest
C     GOTSCATT    O   .TRUE. if s/c orientation is available
C     GOTSCANATT  O   .TRUE. if scanner orientation is available
C
C$ Detailed_Input
C 
C     ET          is the ephemeris time of interest, expressed as
C                 seconds past J2000 TDB.    
C
C$ Detailed_Output
C
C     GOTSCATT    is a logical flag indicating whether C-kernel data
C                 for the MEX_SC_REF spacecraft reference frame are
C                 available at the time indicated by the input argument
C                 ET.  GOTSCATT is set to .TRUE. if pointing data are
C                 available and .FALSE. otherwise.
C
C     GOTSCANATT  is a logical flag indicating whether C-kernel data
C                 for the MEX_ASPERA_SCANNER reference frame are
C                 available at the time indicated by the input argument
C                 ET.  GOTSCANATT is set to .TRUE. if pointing data are
C                 available and .FALSE. otherwise.
C
C$ Parameters
C 
C     None.
C 
C$ Files
C 
C     MEX SCLK file must be loaded prior to calling this function. MEX
C     s/c CK and ASPERA scanner CK should be loaded prior to calling
C     this function.
C 
C$ Exceptions
C
C     If SCLK data have not been loaded prior to calling this function,
C     then an appropriate error will be signaled by the SCLK subsystem.
C
C$ Particulars
C
C     MEX s/c orientation in the loaded CK files is assumed to be
C     provided for the NAIF ID -41001 (attached to the MEX_SC_REF
C     frame).
C
C     ASPERA scanner orientation in the loaded CK files is assumed to
C     be provided for the NAIF ID -41111 (attached to the
C     MEX_ASPERA_SCANNER frame).
C
C$ Examples
C
C
C     In this example the function is called to check for orientation
C     some time in the middle of the Earth-Mars cruise. A CK providing
C     s/c orientation is loaded. No CK providing orientation for the
C     ASPERA scanner is loaded.
C
C
C        PROGRAM CHKCRUISE
C        IMPLICIT NONE
C
C        DOUBLE PRECISION      ET
C        LOGICAL               GOTSCATT
C        LOGICAL               GOTSCANATT
C
C  C
C  C     Load LSK, MEX SCLK, and MEX s/c orientation CK files. 
C  C
C        CALL FURNSH ( 'naif0007.tls'                         )
C        CALL FURNSH ( 'mex_030618_step.tsc'                  )
C        CALL FURNSH ( 'ATNM_PSTPIX_DBP030602191822_00021.bc' )
C
C  C
C  C     Convert UTC to ET. 
C  C
C        CALL STR2ET ( '2003-09-09 12:00', ET )
C
C  C
C  C     Check for CK data. 
C  C     
C        CALL CHECKCK ( ET, GOTSCATT, GOTSCANATT )
C
C  C
C  C     Report data availability.
C  C
C        WRITE ( *, '(1X,A,L10)' ) 'SPACECRAFT ATTITUDE: ', GOTSCATT
C        WRITE ( *, '(1X,A,L10)' ) 'SCANNER ATTITUDE:    ', GOTSCANATT
C
C        END
C
C
C$ Restrictions
C 
C     None.
C
C$ Author_and_Institution
C 
C     B.V. Semenov    (JPL)
C     N.J. Bachman    (JPL)
C 
C$ Literature_References
C 
C     None.
C 
C$ Version
C 
C-    CHECKCK Version 1.0.0, 15-AUG-2003 (BVS) (NJB)
C
C-&


C
C     Local variables
C     
      DOUBLE PRECISION      CLKOUT
      DOUBLE PRECISION      CMAT  ( 3, 3 )
      DOUBLE PRECISION      SCLKDP

C
C     To verify that loaded CK files (if any) contain spacecraft and
C     scanner orientation data one needs to call a lower level CK
C     access routine, CKGP, which requires encoded SCLK as input
C     time, so ET should be converted to it first.
C
      CALL SCE2C ( -41, ET, SCLKDP )

C
C     MEX s/c orientation is attached to NAIF ID -41001 (MEX_SC_REF)
C     frame. Call CKGP to see if there is orientation available for
C     this ID at specified time. The only CKGP output of interest is
C     the last one -- the flag indicating that the orientation is
C     available.
C
      CALL CKGP ( -41001,   SCLKDP,  0.0D0,      
     .            'J2000',  CMAT,    CLKOUT,  GOTSCATT )

C
C     ASPERA scanner orientation is attached to the NAIF ID -41111
C     (MEX_ASPERA_SCANNER) frame. Again call CKGP to see if there is
C     orientation available for this ID at specified time. As before,
C     the only CKGP output of interest is the last one -- the flag
C     indicating that the orientation is available.
C
      CALL CKGP ( -41111,   SCLKDP,  0.0D0,      
     .            'J2000',  CMAT,    CLKOUT,  GOTSCANATT )

      END


 
